"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const core_1 = require("@material-ui/core");
const core_2 = require("@material-ui/core");
const React = require("react");
const react_redux_1 = require("react-redux");
const services_1 = require("../services");
const store_1 = require("../store");
const page_widgets_1 = require("./page-widgets");
/**
 * maps state fields from the store to component props
 * @param state the redux state
 */
const mapStateToProps = (state, ownProps) => {
    return {
        documentData: state.sensenetDocumentViewer.documentState.document,
        version: state.sensenetDocumentViewer.documentState.version,
        page: state.sensenetDocumentViewer.previewImages.AvailableImages[ownProps.imageIndex - 1] || {},
        activePages: state.sensenetDocumentViewer.viewer.activePages,
        showWatermark: state.sensenetDocumentViewer.viewer.showWatermark,
        pollInterval: state.sensenetDocumentViewer.previewImages.pollInterval,
    };
};
/**
 * maps state actions from the store to component props
 * @param state the redux state
 */
const mapDispatchToProps = {
    previewAvailable: store_1.previewAvailable,
};
class Page extends React.Component {
    constructor() {
        super(...arguments);
        this.pollPreview = setInterval(() => {
            if (this.state.isPolling) {
                this.props.previewAvailable(this.props.documentData, this.props.version, this.props.imageIndex);
            }
        }, this.props.pollInterval);
        /** the component state */
        this.state = Page.getDerivedStateFromProps(this.props);
    }
    stopPolling() {
        if (this.pollPreview) {
            clearInterval(this.pollPreview);
            this.pollPreview = undefined;
        }
    }
    /** event before the component did unmount */
    componentWillUnmount() {
        this.stopPolling();
    }
    /**
     * Returns a derived state from the specified props
     * @param props The props for state creation
     */
    static getDerivedStateFromProps(props) {
        const imageRotation = services_1.ImageUtil.normalizeDegrees(props.page.Attributes && props.page.Attributes.degree || 0);
        const imageRotationRads = (imageRotation % 180) * Math.PI / 180;
        const imgSrc = (props.image === 'preview' ? props.page.PreviewImageUrl : props.page.ThumbnailImageUrl) || '';
        const relativePageSize = services_1.ImageUtil.getImageSize({
            width: props.viewportWidth,
            height: props.viewportHeight,
        }, {
            width: props.page.Width,
            height: props.page.Height,
            rotation: props.page.Attributes && props.page.Attributes.degree || 0,
        }, props.zoomMode, props.zoomLevel);
        const boundingBox = services_1.ImageUtil.getRotatedBoundingBoxSize({
            width: props.page.Width,
            height: props.page.Height,
        }, imageRotation);
        const maxDiff = (relativePageSize.height - relativePageSize.width) / 2;
        const diffHeight = Math.sin(imageRotationRads) * maxDiff;
        return {
            isActive: props.activePages.indexOf(props.page.Index) >= 0,
            imgSrc,
            pageWidth: relativePageSize.width,
            pageHeight: relativePageSize.height,
            zoomRatio: relativePageSize.height / props.page.Height,
            imageWidth: `${100 * boundingBox.zoomRatio}%`,
            imageHeight: `${100 * boundingBox.zoomRatio}%`,
            imageTransform: `translateY(${diffHeight}px) rotate(${imageRotation}deg)`,
            isPolling: !(imgSrc ? true : false),
        };
    }
    /**
     * renders the component
     */
    render() {
        const elementName = `${this.props.elementNamePrefix}${this.props.page.Index}`;
        return (React.createElement(core_1.Paper, { elevation: this.state.isActive ? 8 : 2, id: elementName, style: { margin: this.props.margin } },
            React.createElement("div", { style: {
                    padding: 0,
                    overflow: 'hidden',
                    width: this.state.pageWidth - 2 * this.props.margin,
                    height: this.state.pageHeight - 2 * this.props.margin,
                    position: 'relative',
                }, onClick: (ev) => this.props.onClick(ev) },
                this.props.showWidgets ?
                    React.createElement("div", null,
                        React.createElement(page_widgets_1.ShapesWidget, { zoomRatio: this.state.zoomRatio, page: this.props.page, viewPort: { height: this.state.pageHeight, width: this.state.pageWidth } }))
                    : null,
                React.createElement("span", { style: { display: 'flex', justifyContent: 'center' } }, this.state.imgSrc ?
                    React.createElement("img", { src: `${this.state.imgSrc}${this.props.showWatermark ? '?watermark=true' : ''}`, style: { transition: 'transform .1s ease-in-out', width: this.state.imageWidth, height: this.state.imageHeight, transform: this.state.imageTransform } }) :
                    React.createElement(core_2.CircularProgress, { style: { marginTop: '50%' } })))));
    }
}
const connectedComponent = react_redux_1.connect(mapStateToProps, mapDispatchToProps)(Page);
exports.Page = connectedComponent;
//# sourceMappingURL=Page.js.map