"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const core_1 = require("@material-ui/core");
const icons_1 = require("@material-ui/icons");
const React = require("react");
const react_redux_1 = require("react-redux");
const store_1 = require("../../store");
/**
 * The amount of rotation in degrees
 */
const ROTATION_AMOUNT = 90;
/**
 * maps state fields from the store to component props
 * @param state the redux state
 */
exports.mapStateToProps = (state, ownProps) => {
    return {
        rotateLeft: state.sensenetDocumentViewer.localization.rotatePageLeft,
        rotateRight: state.sensenetDocumentViewer.localization.rotatePageRight,
    };
};
/**
 * maps state actions from the store to component props
 * @param state the redux state
 */
exports.mapDispatchToProps = {
    rotateImages: store_1.rotateImages,
    rotateShapesForPages: store_1.rotateShapesForPages,
};
/**
 * Page widget component for rotating a specified page
 */
class RotatePageComponent extends React.Component {
    rotatePageLeft() {
        this.props.rotateImages([this.props.page.Index], -ROTATION_AMOUNT);
        this.props.rotateShapesForPages([{ index: this.props.page.Index, size: { width: this.props.page.Width, height: this.props.page.Height } }], -ROTATION_AMOUNT);
    }
    rotatePageRight() {
        this.props.rotateImages([this.props.page.Index], ROTATION_AMOUNT);
        this.props.rotateShapesForPages([{ index: this.props.page.Index, size: { width: this.props.page.Width, height: this.props.page.Height } }], ROTATION_AMOUNT);
    }
    /**
     * renders the component
     */
    render() {
        return (React.createElement("div", { style: { position: 'absolute', zIndex: 1, top: 0, right: 0, filter: 'drop-shadow(0 0 3px white) drop-shadow(0 0 5px white) drop-shadow(0 0 9px white)' } },
            React.createElement(core_1.IconButton, { title: this.props.rotateLeft },
                React.createElement(icons_1.RotateLeft, { onClick: () => this.rotatePageLeft() })),
            React.createElement(core_1.IconButton, { title: this.props.rotateRight },
                React.createElement(icons_1.RotateRight, { onClick: () => this.rotatePageRight() }))));
    }
}
exports.RotatePageComponent = RotatePageComponent;
const connectedComponent = react_redux_1.connect(exports.mapStateToProps, exports.mapDispatchToProps)(RotatePageComponent);
exports.RotatePageWidget = connectedComponent;
//# sourceMappingURL=RotatePage.js.map