/// <reference types="react-redux" />
import * as React from 'react';
import { Annotation, PreviewImageData, Shape, Shapes } from '../../models';
import { componentType, Dimensions } from '../../services';
import { RootReducerType } from '../../store';
/**
 * Defined the component's own properties
 */
export interface OwnProps {
    viewPort: Dimensions;
    page: PreviewImageData;
    zoomRatio: number;
}
/**
 * maps state fields from the store to component props
 * @param state the redux state
 */
export declare const mapStateToProps: (state: RootReducerType, ownProps: OwnProps) => {
    showShapes: boolean;
    showRedactions: boolean;
    canHideRedactions: boolean;
    redactions: Shape[];
    highlights: Shape[];
    annotations: Annotation[];
    canEdit: boolean;
};
/**
 * maps state actions from the store to component props
 * @param state the redux state
 */
export declare const mapDispatchToProps: {
    updateShapeData: <K extends "redactions" | "highlights" | "annotations">(shapeType: K, shapeGuid: string, shapeData: Shapes[K][0]) => {
        type: string;
        shapeType: K;
        shapeGuid: string;
        shapeData: Shapes[K][0];
    };
};
/**
 * Page widget component for displaying shapes on a page
 */
export declare class ShapesComponent extends React.Component<componentType<typeof mapStateToProps, typeof mapDispatchToProps, OwnProps>> {
    private onDrop;
    /**
     * renders the component
     */
    render(): JSX.Element;
}
declare const connectedComponent: React.ComponentClass<Pick<{
    showShapes: boolean;
    showRedactions: boolean;
    canHideRedactions: boolean;
    redactions: Shape[];
    highlights: Shape[];
    annotations: Annotation[];
    canEdit: boolean;
} & {
    updateShapeData: <K extends "redactions" | "highlights" | "annotations">(shapeType: K, shapeGuid: string, shapeData: Shapes[K][0]) => {
        type: string;
        shapeType: K;
        shapeGuid: string;
        shapeData: Shapes[K][0];
    };
} & OwnProps, "page" | "zoomRatio" | "viewPort"> & OwnProps> & {
    WrappedComponent: React.ComponentType<{
        showShapes: boolean;
        showRedactions: boolean;
        canHideRedactions: boolean;
        redactions: Shape[];
        highlights: Shape[];
        annotations: Annotation[];
        canEdit: boolean;
    } & {
        updateShapeData: <K extends "redactions" | "highlights" | "annotations">(shapeType: K, shapeGuid: string, shapeData: Shapes[K][0]) => {
            type: string;
            shapeType: K;
            shapeGuid: string;
            shapeData: Shapes[K][0];
        };
    } & OwnProps>;
};
export { connectedComponent as ShapesWidget };
