import { Action } from 'redux';
import { Reducer } from 'redux';
import { InjectableAction } from 'redux-di-middleware';
import { RootReducerType } from '.';
import { DocumentData, PreviewImageData } from '../models';
/**
 * Preview images store model definition
 */
export interface PreviewImagesStateType {
    /**
     * The polling interval in milliseconds
     */
    pollInterval: number;
    /**
     * The received available images
     */
    AvailableImages: PreviewImageData[];
    /**
     * Flag that indicates if there are some changes (e.g. rotation)
     */
    hasChanges: boolean;
    /**
     * The error message if there was error fetching image data
     */
    error: string | null;
}
/**
 * Action that updates the store when the preview image fetching starts
 * @param documentData the provided document data
 */
export declare const getAvailabelImagesAction: (documentData: DocumentData) => {
    type: string;
    documentData: DocumentData;
};
/**
 * Action that updates the store with the received image data
 * @param imageData the received image data
 */
export declare const availabelImagesReceivedAction: (imageData: PreviewImageData[]) => {
    type: string;
    imageData: PreviewImageData[];
};
/**
 * Action that updates the store with an error message when a fetching error happens
 * @param error The error message
 */
export declare const availabelImagesReceiveErrorAction: (error: string) => {
    type: string;
    error: string;
};
/**
 * Action that rotates the pages with the provided index(es) with a given angle
 * @param imageIndexes The image indexes to rotate
 * @param amount The rotation amount in degrees
 */
export declare const rotateImages: (imageIndexes: number[], amount: number) => {
    type: string;
    imageIndexes: number[];
    amount: number;
};
/**
 * Thunk action that fetches the available image info from the provided API endpoint
 * @param documentData
 * @param version
 */
export declare const getAvailableImages: (documentData: DocumentData, version?: string) => InjectableAction<RootReducerType, Action>;
/**
 * Action that updates the store with the provided document data
 * @param documentData
 * @param version
 * @param page
 */
export declare const previewAvailableAction: (documentData: DocumentData, version: string, page: number) => {
    type: string;
    documentData: DocumentData;
};
/**
 * Action that updates the store with the received image data
 * @param documentData
 * @param version
 * @param page
 * @param imageData
 */
export declare const previewAvailableReceivedAction: (documentData: DocumentData, version: string, page: number, imageData: PreviewImageData) => {
    type: string;
    documentData: DocumentData;
    version: string;
    page: number;
    imageData: PreviewImageData;
};
/**
 * Action that updates the state when no preview images are available
 */
export declare const previewNotAvailableReceivedAction: () => {
    type: string;
};
/**
 * Action that updates the state with an error message
 * @param error The error message
 */
export declare const previewAvailableErrorAction: (error: string) => {
    type: string;
    error: string;
};
/**
 * Action that sets the polling interval
 * @param pollInterval the new polling interval in millisecs
 */
export declare const setPagePollInterval: (pollInterval: number) => {
    type: string;
    pollInterval: number;
};
/**
 * Thunk action that fetches the available images from the provided API endpoint
 * @param documentData
 * @param version
 * @param page
 */
export declare const previewAvailable: (documentData: DocumentData, version?: string, page?: number) => InjectableAction<RootReducerType, Action>;
/**
 * Reducer for the preview images
 * @param state the current state
 * @param action the dispatched action
 */
export declare const previewImagesReducer: Reducer<PreviewImagesStateType>;
